@@ -1,13 +1,18 @@
 print.data.list <-
 function(x, ...){
 	
+	repdim <- dim(x)
+	x <- unclass(x)
+	
 	# print each variable in x
 	for(i in seq_along(x)){
 		
 		# get information about the variable
 		subsetdim <- attr(x[[i]],"subsetdim")
-		attr(x[[i]],"subsetdim") <- NULL
-		varname <- varnames(x)[i]	# could be out of the loop?
+		attr(x[[i]], "subsetdim") <- NULL
+		attr(x[[i]], "contrasts") <- NULL
+		#varname <- varnames(x)[i]	# could be out of the loop?
+		varname <- names(x)[i]
 		
 		if(is.null(varname)) varname <- i
 		
@@ -15,8 +20,9 @@ function(x, ...){
 		cat(paste(varname,":\n",sep=""))
 		cat(rep("-",nchar(varname)),"\n",sep="")
 		
-		# print the variable
-		print(x[[i]])
+		# print the variable (the call to [ is intended to remove attributes)
+		print(do.call(`[`, c(list(x[[i]]), lapply(dim(x[[i]]), seq.int), list(drop = FALSE))))
+		#print(x[[i]]) # older version of the above line
 		
 		# print replication dimensions for variable
 		cat("Replicated along:  || ",
@@ -27,8 +33,9 @@ function(x, ...){
 	
 	# print overall replication dimensions
 	cat("REPLICATION DIMENSIONS: \n")
-	repdim <- dim(x)
+	#repdim <- dim(x)
 	names(repdim) <- names(subsetdim)
 	print(repdim)
 }
 
+
